Release History
===============

**2.0.3 - 2020-11-11**

    *   preparation for publishing
    *   corrected the URL for help/documentation

**2.0.2 - 2020-11-10**

    *   configuration file now saved/loaded via menu entries
    *   configuration file is auto-updated when changes happen
    *   logging to file now into hcpmqe.<pid>.log

**2.0.1 - 2020-11-08**

    *   automatically adopts to whatever metadata fields the HCP MQE API
        delivers

    *   allows to restart a canceled or interrupted query

**2.0.0 - 2020-11-03**

    *   complete re-write using tkinter through pySimpleGUI

    *   runs on all major platforms (Linux, Windows, macOS)

**1.0.x releases**

*   1.0.11 - 2014-08-21

    [..]

*   1.0.1 - 2012-09-06

    initial release for Windows only
